==> openvino_model_api-0.2.2.tar.gz: openvino_model_api-0.2.2/model_api/models/__init__.py <==
"""
 Copyright (C) 2021-2024 Intel Corporation

 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
 You may obtain a copy of the License at

      http://www.apache.org/licenses/LICENSE-2.0

 Unless required by applicable law or agreed to in writing, software
 distributed under the License is distributed on an "AS IS" BASIS,
 WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 See the License for the specific language governing permissions and
 limitations under the License.
"""

from .action_classification import ActionClassificationModel
from .anomaly import AnomalyDetection
from .background_matting import (
    ImageMattingWithBackground,
    PortraitBackgroundMatting,
    VideoBackgroundMatting,
)
from .bert import BertEmbedding, BertNamedEntityRecognition, BertQuestionAnswering
from .centernet import CenterNet
from .classification import ClassificationModel
from .ctpn import CTPN
from .deblurring import Deblurring
from .detection_model import DetectionModel
from .detr import DETR
from .faceboxes import FaceBoxes
from .hpe_associative_embedding import HpeAssociativeEmbedding
from .image_model import ImageModel
from .instance_segmentation import MaskRCNNModel, YolactModel
from .model import Model
from .monodepth import MonoDepthModel
from .nanodet import NanoDet, NanoDetPlus
from .open_pose import OpenPose
from .retinaface import RetinaFace, RetinaFacePyTorch
from .sam_models import SAMDecoder, SAMImageEncoder
from .segmentation import SalientObjectDetectionModel, SegmentationModel
from .ssd import SSD
from .ultra_lightweight_face_detection import UltraLightweightFaceDetection
from .utils import (
    AnomalyResult,
    ClassificationResult,
    Contour,
    Detection,
    DetectionResult,
    DetectionWithLandmarks,
    ImageResultWithSoftPrediction,
    InstanceSegmentationResult,
    OutputTransform,
    PredictedMask,
    SegmentedObject,
    SegmentedObjectWithRects,
    VisualPromptingResult,
    ZSLVisualPromptingResult,
    add_rotated_rects,
    get_contours,
)
from .visual_prompting import Prompt, SAMLearnableVisualPrompter, SAMVisualPrompter
from .yolo import YOLO, YOLOF, YOLOX, YoloV3ONNX, YoloV4, YOLOv5, YOLOv8

classification_models = [
    "resnet-18-pytorch",
    "se-resnext-50",
    "mobilenet-v3-large-1.0-224-tf",
    "efficientnet-b0-pytorch",
]

detection_models = [
    # "face-detection-retail-0044", # resize_type is wrong or missed in model.yml
    "yolo-v4-tf",
    "ssd_mobilenet_v1_fpn_coco",
    "ssdlite_mobilenet_v2",
]

segmentation_models = [
    "fastseg-small",
]


__all__ = [
    "ActionClassificationModel",
    "AnomalyDetection",
    "AnomalyResult",
    "BertEmbedding",
    "BertNamedEntityRecognition",
    "BertQuestionAnswering",
    "CenterNet",
    "ClassificationModel",
    "Contour",
    "CTPN",
    "Deblurring",
    "DetectionModel",
    "DetectionWithLandmarks",
    "DETR",
    "FaceBoxes",
    "HpeAssociativeEmbedding",
    "ImageMattingWithBackground",
    "ImageModel",
    "ImageResultWithSoftPrediction",
    "InstanceSegmentationResult",
    "VisualPromptingResult",
    "ZSLVisualPromptingResult",
    "PredictedMask",
    "SAMVisualPrompter",
    "SAMLearnableVisualPrompter",
    "MaskRCNNModel",
    "Model",
    "MonoDepthModel",
    "NanoDet",
    "NanoDetPlus",
    "OpenPose",
    "OutputTransform",
    "PortraitBackgroundMatting",
    "RetinaFace",
    "RetinaFacePyTorch",
    "SalientObjectDetectionModel",
    "SegmentationModel",
    "SSD",
    "UltraLightweightFaceDetection",
    "VideoBackgroundMatting",
    "YolactModel",
    "YOLO",
    "YoloV3ONNX",
    "YoloV4",
    "YOLOv5",
    "YOLOv8",
    "YOLOF",
    "YOLOX",
    "SAMDecoder",
    "SAMImageEncoder",
    "ClassificationResult",
    "Prompt",
    "Detection",
    "DetectionResult",
    "DetectionWithLandmarks",
    "classification_models",
    "detection_models",
    "segmentation_models",
    "SegmentedObject",
    "SegmentedObjectWithRects",
    "add_rotated_rects",
    "get_contours",
]

==> openvino_model_api-0.3.0.3.tar.gz: openvino_model_api-0.3.0.3/model_api/models/__init__.py <==
#
# Copyright (C) 2020-2024 Intel Corporation
# SPDX-License-Identifier: Apache-2.0
#

from .action_classification import ActionClassificationModel
from .anomaly import AnomalyDetection
from .classification import ClassificationModel
from .detection_model import DetectionModel
from .image_model import ImageModel
from .instance_segmentation import MaskRCNNModel
from .keypoint_detection import KeypointDetectionModel, TopDownKeypointDetectionPipeline
from .model import Model
from .result import (
    AnomalyResult,
    ClassificationResult,
    Contour,
    DetectedKeypoints,
    DetectionResult,
    ImageResultWithSoftPrediction,
    InstanceSegmentationResult,
    PredictedMask,
    RotatedSegmentationResult,
    VisualPromptingResult,
    ZSLVisualPromptingResult,
)
from .sam_models import SAMDecoder, SAMImageEncoder
from .segmentation import SalientObjectDetectionModel, SegmentationModel
from .ssd import SSD
from .utils import (
    OutputTransform,
    add_rotated_rects,
    get_contours,
)
from .visual_prompting import Prompt, SAMLearnableVisualPrompter, SAMVisualPrompter
from .yolo import YOLO, YOLOF, YOLOX, YoloV3ONNX, YoloV4, YOLOv5, YOLOv8

classification_models = [
    "resnet-18-pytorch",
    "se-resnext-50",
    "mobilenet-v3-large-1.0-224-tf",
    "efficientnet-b0-pytorch",
]

detection_models = [
    # "face-detection-retail-0044", # resize_type is wrong or missed in model.yml
    "yolo-v4-tf",
    "ssd_mobilenet_v1_fpn_coco",
    "ssdlite_mobilenet_v2",
]

segmentation_models = [
    "fastseg-small",
]


__all__ = [
    "ActionClassificationModel",
    "add_rotated_rects",
    "AnomalyDetection",
    "AnomalyResult",
    "classification_models",
    "ClassificationModel",
    "ClassificationResult",
    "Contour",
    "detection_models",
    "DetectedKeypoints",
    "DetectionModel",
    "DetectionResult",
    "get_contours",
    "ImageModel",
    "ImageResultWithSoftPrediction",
    "InstanceSegmentationResult",
    "KeypointDetectionModel",
    "Label",
    "MaskRCNNModel",
    "Model",
    "OutputTransform",
    "PredictedMask",
    "Prompt",
    "RotatedSegmentationResult",
    "SAMDecoder",
    "SAMImageEncoder",
    "SAMLearnableVisualPrompter",
    "SAMVisualPrompter",
    "SalientObjectDetectionModel",
    "segmentation_models",
    "SegmentationModel",
    "SSD",
    "TopDownKeypointDetectionPipeline",
    "VisualPromptingResult",
    "YOLO",
    "YOLOF",
    "YOLOv3ONNX",
    "YOLOv4",
    "YOLOv5",
    "YOLOv8",
    "YOLOX",
    "ZSLVisualPromptingResult",
    "YoloV3ONNX",
    "YoloV4",
]
